@@ -9,5 +9,5 @@ class Oracle:
     def set_exchange_rates(self, exchange_rates: ExchangeRateHolder):
         pass
 
-    def predict(self, instrument, exchanged_from=None, instant=None) -> Optional[Prediction]:
+    def predict(self, instrument, exchanged_from, instant) -> Optional[Prediction]:
         pass
